@@ -36,7 +36,7 @@ namespace Cantor
 class CANTORTEST_EXPORT BackendTest : public QObject
 {
     Q_OBJECT
-    private slots:
+    private Q_SLOTS:
         void initTestCase();
         void cleanupTestCase();
 
